Learn R Programming

qris (version 1.1.1)

qris.extend: Extend a "qris" object to a specified range of \(tau\) or \(t_0\) values.

Description

Extend a "qris" object to a specified range of \(tau\) or \(t_0\) values.

Usage

qris.extend(x, t0s = NULL, Qs = NULL, nB = NULL, vari = NULL)

Arguments

x

is an qris object or a data.frame returned by plot.qris

t0s

is a vector of range of t0 to plot; when not specified, the default value is from 0 to presently defined \(t_0\)

Qs

is a vector of range of Q to plot; when not specified, the default value is from 5% to presently defined \(Q\)

nB

is the number of multiplier bootstrapping for standard error estimation.

vari

is a character string to choose variables to draw the regression coefficient.