Learn R Programming

qris (version 1.1.1)

residuals.qris: Residuals for Quantile Regression Model Fitted on Residual life

Description

Residual based on fitted quantile regression model

Usage

# S3 method for qris
residuals(object, newdata, ...)

Value

A vector of residual

Arguments

object

is a qris object

newdata

is a data frame for an optional new data to do predictions. If omitted, the fitted values based on the original data and fit will be returned.

...

for future extension