qris" object to a specified range of \(tau\) or \(t_0\) values.Extend a "qris" object to a specified range of \(tau\) or \(t_0\) values.
qris.extend(x, t0s = NULL, Qs = NULL, nB = NULL, vari = NULL)is an qris object or a data.frame returned by plot.qris
is a vector of range of t0 to plot; when not specified, the default value is from 0 to presently defined \(t_0\)
is a vector of range of Q to plot; when not specified, the default value is from 5% to presently defined \(Q\)
is the number of multiplier bootstrapping for standard error estimation.
is a character string to choose variables to draw the regression coefficient.